/*
  Photo Collage Engine 
 by Eiichi Ishii 
 
 ※動作にはProcessingが必要です。
 https://www.processing.org
 
 [ 注意 ]
 ・コラージュの素材となる画像を用意してください。このとき、画像の名前を
 「 1.jpg, 2.jpg, 3.jpg …」としてください。
 ・プログラムを実行する前に、コラージュする画像を/Photo Collage Engine/dataに
 　ドラック&ドロップし、プログラム2行目 : int n = 10; の値を写真の枚数に合わせて
 　変更してください。
 
 [ 使い方 ]
 ・マウスをクリックすると、写真の位置を変更します。（ランダム）
 ・左上の四角いスイッチを押すと、背景色の切り替えができます。
 ・いずれかのキーを押すと、コラージュした画像を保存します。
 ・各パラメータは必要に応じて変更してください。
 
 © Eiichi Ishii  2014
 http://eiichiishii-web.jimdo.com
 */

PImage img[]; 
int n=10; //写真の枚数に合わせてここの値を変更してください
int s=0;
boolean flag;
int bg=0;
int st=255;

void setup() {
  img = new PImage[n+1];
  for (int i=1; i<n+1; i++) {
    img[i]=loadImage(i+".jpg");
  }
  size(1062, 1062);
  rectMode(CENTER);
  imageMode(CENTER);
  collage();
}

void draw() {
}

void collage() {
  background(bg);
  int cx=width/2;
  int cy=height/2;
  for (int i=1; i<n+1; i++) {
    int x=int(random(width));
    int y=int(random(height));
    if ((x-cx)*(x-cx)+(y-cy)*(y-cy) <width/2.5*height/2.5) {
      pushMatrix();
      translate(x, y);
      scale(random(0.2, 0.6));
      rotate(radians(random(360)));
      tint(255, 150);
      image(img[i], 0, 0);
      popMatrix();
    }
  }
  stroke(st);
  strokeWeight(10);
  point(width/2, height/2);
  noFill();
  strokeWeight(0.5);
  ellipse(width/2, height/2, width, height);
  fill(st);
  noStroke();
  rect(width/12, height/12, 20, 20);
  stroke(st);
  noFill();
  rect(width/12, height/12, 26, 26);
  text("Photo Collage Engine", width/32, height/28);
  text("by Eiichi Ishii", width/32, height/20);
  text("background", width/20, height/9);
}

void mousePressed() {
  if (mouseX>=width/12-20 && mouseX<=width/12+20 && mouseY>=height/12-20 && mouseY<=height/12+20) {
    if (flag==false) { 
      bg=0;
      st=255;
      flag=true;
    }
    else {           
      bg=255;
      st=0;
      flag=false;
    }
  }
  collage();
}

void keyTyped() {
  s++;
  //filter(INVERT);
  //filter(GRAY);
  save("collage-"+s+".jpg");
}

